import numpy as np
import datetime

def checkpoint(end, begin):
    seconds_all = (end - begin).seconds
    hours = int(seconds_all / 3600)
    minutes = int((seconds_all - hours * 3600) / 60)
    seconds = seconds_all - hours * 3600 - minutes * 60
    print('{:,} hours, {:,} minutes, and {:,} seconds'.format(hours, minutes, seconds))

def unique_array(iterable):
    return np.unique(np.array([x for x in iterable if str(x) != 'nan' and str(x) != 'None' and str(x).lower() != 'nat']))

def isiter(obj, var_name):
    try:
        iter(obj)
    except TypeError as te:
        return "'{}' is not iterable (Full Error: {})".format(var_name, te)


from setuptools import setup, find_packages
from os import path


current_dir = path.abspath(path.dirname(__file__))
with open(path.join(current_dir, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(name='gaplearn',
      version='0.9',
      description='Bridging gaps between other machine learning and deep learning tools and making robust, post-mortem analysis possible.',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='http://github.com/awhedon/gaplearn',
      author='Alexander Whedon',
      author_email='alexander.whedon@gmail.com',
      license='MIT',
      packages=find_packages(),
      install_requires = [
          'pandas',
          'numpy',
          'sklearn',
          'eli5'
      ],
      zip_safe=False)